@@ -21,7 +21,8 @@ package avatica
 
 import (
 	"database/sql/driver"
-	"fmt"
+
+	"golang.org/x/xerrors"
 )
 
 func driverNamedValueToNamedValue(values []driver.NamedValue) ([]namedValue, error) {
@@ -31,7 +32,7 @@ func driverNamedValueToNamedValue(values []driver.NamedValue) ([]namedValue, err
 		list[i] = namedValue(nv)
 
 		if nv.Name != "" {
-			return list, fmt.Errorf("named parameters are not supported: %s given", nv.Name)
+			return list, xerrors.Errorf("named parameters are not supported: %s given", nv.Name)
 		}
 	}
 
