@@ -24,6 +24,7 @@ import (
 	"io/ioutil"
 	"os"
 	"path/filepath"
+	"sync"
 	"testing"
 	"time"
 )
@@ -1255,6 +1256,125 @@ func TestHSQLDBMultipleSchemaSupport(t *testing.T) {
 	})
 }
 
+func TestHSQLDBExecBatch(t *testing.T) {
+	skipTestIfNotHSQLDB(t)
+
+	runTests(t, dsn+"?batching=true", func(dbt *DBTest) {
+
+		// Create and seed table
+		dbt.mustExec(`CREATE TABLE ` + dbt.tableName + ` (
+				int INTEGER PRIMARY KEY
+			    )`)
+
+		stmt, err := dbt.db.Prepare(`INSERT INTO ` + dbt.tableName + ` VALUES(?)`)
+
+		if err != nil {
+			dbt.Fatal(err)
+		}
+
+		totalRows := 6
+
+		for i := 1; i <= totalRows; i++ {
+			_, err := stmt.Exec(i)
+
+			if err != nil {
+				dbt.Fatal(err)
+			}
+		}
+
+		// When batching=true, after exec(sql), need to close the stmt
+		err = stmt.Close()
+
+		if err != nil {
+			dbt.Fatal(err)
+		}
+
+		queryStmt, err := dbt.db.Prepare(`SELECT * FROM ` + dbt.tableName + ` WHERE int = ?`)
+
+		if err != nil {
+			dbt.Fatal(err)
+		}
+
+		var res int
+
+		for i := 1; i <= totalRows; i++ {
+
+			err := queryStmt.QueryRow(i).Scan(&res)
+
+			if err != nil {
+				dbt.Fatal(err)
+			}
+
+			if res != i {
+				dbt.Fatalf("Unexpected query result. Expected %d, got %d.", i, res)
+			}
+		}
+	})
+}
+
+func TestHSQLDBExecBatchConcurrency(t *testing.T) {
+	skipTestIfNotHSQLDB(t)
+
+	runTests(t, dsn+"?batching=true", func(dbt *DBTest) {
+
+		// Create and seed table
+		dbt.mustExec(`CREATE TABLE ` + dbt.tableName + ` (
+				int INTEGER PRIMARY KEY
+			    )`)
+
+		stmt, err := dbt.db.Prepare(`INSERT INTO ` + dbt.tableName + ` VALUES(?)`)
+
+		if err != nil {
+			dbt.Fatal(err)
+		}
+
+		totalRows := 6
+
+		var wg sync.WaitGroup
+		for i := 1; i <= totalRows; i++ {
+			wg.Add(1)
+			go func(num int) {
+				defer wg.Done()
+
+				_, err := stmt.Exec(num)
+
+				if err != nil {
+					dbt.Fatal(err)
+				}
+			}(i)
+		}
+		wg.Wait()
+
+		// When batching=true, after exec(sql), need to close the stmt
+		err = stmt.Close()
+
+		if err != nil {
+			dbt.Fatal(err)
+		}
+
+		queryStmt, err := dbt.db.Prepare(`SELECT * FROM ` + dbt.tableName + ` WHERE int = ?`)
+
+		if err != nil {
+			dbt.Fatal(err)
+		}
+
+		var res int
+
+		for i := 1; i <= totalRows; i++ {
+
+			err := queryStmt.QueryRow(i).Scan(&res)
+
+			if err != nil {
+				dbt.Fatal(err)
+			}
+
+			if res != i {
+				dbt.Fatalf("Unexpected query result. Expected %d, got %d.", i, res)
+			}
+		}
+	})
+}
+
 // TODO: Test disabled due to CALCITE-1049
 /*func TestHSQLDBErrorCodeParsing(t *testing.T) {
 
